@@ -1,49 +1,42 @@
 """Houses Base Request"""
 
 from __future__ import annotations
+
 from typing import (
     TypeVar,
-    List,
     Union,
-    Type,
     Optional,
     Iterable,
     Dict,
     Any,
 )
-from abc import abstractmethod
+
 import logging
-from urllib.parse import urlparse
+
 import json
+
 from requests import Response
+
 from pyrestsdk.type.enum import HttpsMethod
 from pyrestsdk.type.model import (
     BaseEntity,
     QueryOption,
     HeaderOption,
 )
-from abc import abstractmethod
-import logging
-from requests import Response
-from pyrestsdk.type.model import BaseEntity
+
 from pyrestsdk.request._request import Request
 
 Logger = logging.getLogger(__name__)
 
 T = TypeVar("T", bound=BaseEntity)
-O = TypeVar("O", QueryOption, HeaderOption)
+Q = TypeVar("Q", bound=QueryOption)
+H = TypeVar("H", bound=HeaderOption)
 
 
 class BaseRequest(Request[T]):
     """The Base Request Type"""
 
-    @abstractmethod
-    def parse_response(
-        self, _response: Optional[Response]
-    ) -> Optional[Union[List[T], T]]:
-        """Parses the response into the expected return"""
-
-    def _parse_options(self, options: Optional[Iterable[O]]) -> None:
+    def _parse_options(self, options: Optional[Iterable[Union[Q, H]]]) -> None:
         """Parses the provided options into either header or query options"""
 
         Logger.info("%s._parse_options: function called", type(self).__name__)
@@ -67,10 +60,14 @@ class BaseRequest(Request[T]):
         """Makes the desired request and returns Response or None"""
 
         Logger.info(
-            "%s._sendRequest: %s request made",
+            "%s._send_request: %s request made",
             type(self).__name__,
             self.request_method.name,
         )
+        
+        if not isinstance(value, dict) and value is not None:
+            value = value.as_dict
+        
 
         match self.request_method:
             case HttpsMethod.GET:
@@ -82,7 +79,7 @@ class BaseRequest(Request[T]):
                 return self._client.post(
                     url=self.request_url,
                     params=str(self.query_options),
-                    data=json.dumps(value.Json) if value is not None else None,
+                    data=json.dumps(value) if value is not None else None,
                 )
             case HttpsMethod.DELETE:
                 self._client.delete(
@@ -97,19 +94,4 @@ class BaseRequest(Request[T]):
                     data=json.dumps(value) if value is not None else None,
                 )
             case other:
-                raise Exception(f"Unknown HTTPS method {self.request_method.name}")
-
-
-def parse_result(obj_type: Type[T], result: Dict, client) -> T:
-    return obj_type(client).from_json(result)
-
-
-def parse_result_list(obj_type: Type[T], results: List, client) -> List[T]:
-    _results: List[T] = []
-
-    for raw_result in results:
-        _entry = obj_type(client).from_json(raw_result)
-        _entry.__client = client
-        _results.append(_entry)
-
-    return _results
+                raise Exception(f"Unknown HTTPS method {self.request_method.name}")
\ No newline at end of file
