@@ -1,15 +1,19 @@
 """Houses Supports Query Options"""
 
-from typing import Protocol
 from pyrestsdk.type.model import QueryOptionCollection
 
 
-class SupportsQueryOptions(Protocol):
+class SupportsQueryOptions:
     """Supports Query Options Type"""
 
     __slots__ = ["_query_options"]
 
     _query_options: QueryOptionCollection
+    
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+        
+        self._query_options = QueryOptionCollection()
 
     @property
     def query_options(self) -> QueryOptionCollection:
