@@ -4,11 +4,8 @@ from __future__ import annotations
 from typing import (
     TypeVar,
     Generic,
-    Type,
-    final,
-    get_args,
 )
-from abc import abstractmethod
+from abc import abstractmethod, ABC
 from pyrestsdk import AbstractServiceClient
 from pyrestsdk.type.model import (
     QueryOption,
@@ -21,23 +18,22 @@ O = TypeVar("O", QueryOption, HeaderOption)
 T = TypeVar("T")
 
 
-class AbstractRequestBuilder(Generic[T]):
+class AbstractRequestBuilder(ABC, Generic[T]):
     """Abstract Request Type"""
+    
+    __slots__ = ["_client","_request_url"]
 
     _client: S
     _request_url: str
 
+    @abstractmethod
     def __init__(self: B, request_url: str, client: S) -> None:
-
-        super().__init__()
-
-        self._request_url: str = request_url
-        self._client = client
+        """Instantiates new object"""
 
     @property
     @abstractmethod
-    def Client(self: B) -> S:
-        """Gets the Client"""
+    def request_client(self: B) -> S:
+        """Gets/Sets the Client"""
 
     @property
     @abstractmethod
